/*
  WeatherC.cpp - Library for providing data to Weathercloud.net
  Created by: David Snell
  Last Update: 12/4/2015
*/

#include "Arduino.h"
#include "WeatherC.h"

void WeatherC::Init( ){
  // Initializing function for WeatherC. Just sets all the sensors to -1000 as an "unset" value.
  for( int Index = 0; Index < MaxSensors; Index++ ){ // Run through the maximum number of sensors.
    SensorReadings[ Index ] = -1000;
  }
}

void WeatherC::PostData() {
  // Function to post data to Weathercloud
  if( millis() > PostTime ){ // If it has been long enough between postings
    WeatherClient.stop(); // Stop any client running in preparation to connect.
    WeatherClient.connect( TargetDNS, TargetPort ); // Connect to the target
    if ( WeatherClient.connected() ) { // If the client connected
      WeatherClient.print( "GET /set/wid/" );
      WeatherClient.print( ID ); // Sending the ID provided
      WeatherClient.print( "/key/" );
      WeatherClient.print( Key ); // Sending the Key provided
      for( int Index = 0; Index < MaxSensors; Index++ ){ // Run through the maximum number of sensors.
        if( SensorReadings[ Index ] != -1000 ) { // If the sensor value is not equal to -1000, post it
          WeatherClient.print( "/" );
          WeatherClient.print( SensorNames[ Index ] ); // Add the SensorName to the string
          WeatherClient.print( "/" );
          WeatherClient.print( SensorReadings[ Index ] ); // Add the SensorReading to the string
        }
      }
      WeatherClient.print( "/ver/" );
      WeatherClient.print( Version ); // Sending the Version required.
      WeatherClient.print( "/type/" );
      WeatherClient.print( Type ); // Sending the Type required.
      WeatherClient.println( " HTTP/1.1" );
      WeatherClient.print( "Host: " );
      WeatherClient.println( TargetDNS ); // Sending the TargetDNS required. Not sure exactly, it is an HTTP thing.
      WeatherClient.println( "User-agent: arduino-ethernet" );
      WeatherClient.println( "Connection: close" );
      WeatherClient.println();
    }
    PostTime = ( millis() + PostDelay ); // Set the next time that a posting can occur
  }
}